@@ -12,14 +12,14 @@
 #include "profilesmodel.h"
 #include <KRunner/AbstractRunner>
 
-using namespace Plasma;
+using namespace KRunner;
 
 class KateSessions : public AbstractRunner
 {
     Q_OBJECT
 
 public:
-    explicit KateSessions(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
+    explicit KateSessions(QObject *parent, const KPluginMetaData &metaData);
 
     void init() override;
     void match(RunnerContext &context) override;
