@@ -24,7 +24,7 @@ class WcpotdProvider : public PotdProvider
     Q_OBJECT
 
 public:
-    WcpotdProvider(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
+    explicit WcpotdProvider(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
 
 private:
     void pageRequestFinished(KJob *job);
